`ensembleGroups.ensembleData` <-
function(x) 
{ 
 attr(x, "exchangeable")
}

